( cd usr/bin ; rm -rf ps )
( cd usr/bin ; ln -sf /bin/ps ps )
( cd usr/bin ; rm -rf free )
( cd usr/bin ; ln -sf /bin/free free )
( cd usr/bin ; rm -rf pgrep )
( cd usr/bin ; ln -sf pkill pgrep )
( cd usr/bin ; rm -rf snice )
( cd usr/bin ; ln -sf skill snice )
